@@ -4,9 +4,9 @@
 #include <QStringList>
 
 #include "listwindow.h"
+#include "book.h"
 
 class QCloseEvent;
-class Book;
 
 /** Dialog box managing bookmarks. */
 class BookmarksDialog: public ListWindow
@@ -23,10 +23,15 @@ signals:
 public slots:
     void onGo();
     void onAdd();
-    void onDelete(bool really = false);
+    void onDelete();
+    void onEdit();
     void onItemActivated(const QModelIndex &index);
 
 protected:
+    void reallyDelete();
+    QString bookmarkToText(const Book::Bookmark &bookmark);
+
+private:
     Book *book;
     QStringList data;
 };
