@@ -6,6 +6,7 @@
 
 class QString;
 
+/** Persistent storage for book meta-data. */
 class BookDb
 {
 public:
@@ -14,6 +15,7 @@ public:
     QVariantHash load(const QString &book);
     void save(const QString &book, const QVariantHash &data);
     void remove(const QString &book);
+    void removeAll();
     QStringList books();
 
 private:
