@@ -15,17 +15,18 @@ class Settings: public QObject
     Q_OBJECT
 
 public:
-    explicit Settings(QObject *parent = 0);
     static Settings *instance();
     static void close();
     QVariant value(const QString &key, const QVariant &defaultValue = QVariant())
         const;
     void setValue(const QString &key, const QVariant &value);
+    void apply();
 
 signals:
-    void valueChanged(const QString &name);
+    void valueChanged(const QString &key);
 
-public slots:
+protected:
+    Settings();
 };
 
 #endif // SETTINGS_H
